@@ -143,7 +143,7 @@ typedef enum {
 	CD_SENSOR_KIND_DUMMY,
 	CD_SENSOR_KIND_HUEY,
 	CD_SENSOR_KIND_COLOR_MUNKI,
-	CD_SENSOR_KIND_SPYDER,
+	CD_SENSOR_KIND_SPYDER,		/* not used since 0.1.16 */
 	CD_SENSOR_KIND_DTP20,
 	CD_SENSOR_KIND_DTP22,
 	CD_SENSOR_KIND_DTP41,
@@ -153,6 +153,9 @@ typedef enum {
 	CD_SENSOR_KIND_I1_PRO,
 	CD_SENSOR_KIND_COLORIMTRE_HCFR,
 	CD_SENSOR_KIND_I1_DISPLAY3,	/* Since: 0.1.14 */
+	CD_SENSOR_KIND_COLORHUG,	/* Since: 0.1.15 */
+	CD_SENSOR_KIND_SPYDER2,		/* Since: 0.1.16 */
+	CD_SENSOR_KIND_SPYDER3,		/* Since: 0.1.16 */
 	CD_SENSOR_KIND_LAST
 } CdSensorKind;
 
@@ -220,6 +223,20 @@ typedef enum {
 #define CD_PROFILE_METADATA_DATA_SOURCE_TEST	"test"			/* Since: 0.1.14 */
 #define CD_PROFILE_METADATA_MAPPING_FORMAT	"MAPPING_format"
 #define CD_PROFILE_METADATA_MAPPING_QUALIFIER	"MAPPING_qualifier"
+#define CD_PROFILE_METADATA_MAPPING_DEVICE_ID	"MAPPING_device_id"
+#define CD_PROFILE_METADATA_ACCURACY_DE76_AVG	"ACCURACY_dE76_avg"	/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_ACCURACY_DE76_MAX	"ACCURACY_dE76_max"	/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_ACCURACY_DE76_RMS	"ACCURACY_dE76_rms"	/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_MEASUREMENT_DEVICE	"MEASUREMENT_device"	/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_SCREEN_SURFACE	"SCREEN_surface"	/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_SCREEN_SURFACE_MATTE 	"matte"		/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_SCREEN_SURFACE_GLOSSY	"glossy"	/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_CONNECTION_TYPE	"CONNECTION_type"	/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_CONNECTION_TYPE_INTERNAL	"internal"	/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_CONNECTION_TYPE_VGA		"vga"		/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_CONNECTION_TYPE_DVI		"dvi"		/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_CONNECTION_TYPE_HDMI	"hdmi"		/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_CONNECTION_TYPE_DISPLAYPORT	"displayport"	/* Since: 0.1.16 */
 
 /* defined in org.freedesktop.ColorManager.Profile.xml */
 #define CD_PROFILE_PROPERTY_FILENAME		"Filename"
