@@ -34,6 +34,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <string.h>
 
 #include "cd-profile.h"
@@ -67,6 +68,7 @@ struct _CdProfilePrivate
 	gint64			 created;
 	gboolean		 has_vcgt;
 	gboolean		 is_system_wide;
+	guint			 owner;
 	GHashTable		*metadata;
 };
 
@@ -85,6 +87,7 @@ enum {
 	PROP_HAS_VCGT,
 	PROP_IS_SYSTEM_WIDE,
 	PROP_SCOPE,
+	PROP_OWNER,
 	PROP_LAST
 };
 
@@ -166,6 +169,24 @@ cd_profile_get_filename (CdProfile *profile)
 	return profile->priv->filename;
 }
 
+/**
+ * cd_profile_has_access:
+ * @profile: a #CdProfile instance.
+ *
+ * Gets if the current user has access permissions to the profile.
+ *
+ * Return value: A string, or %NULL for invalid
+ *
+ * Since: 0.1.13
+ **/
+gboolean
+cd_profile_has_access (CdProfile *profile)
+{
+	g_return_val_if_fail (CD_IS_PROFILE (profile), FALSE);
+	g_return_val_if_fail (profile->priv->proxy != NULL, FALSE);
+	return g_access (profile->priv->filename, R_OK) == 0;
+}
+
 /**
  * cd_profile_get_qualifier:
  * @profile: a #CdProfile instance.
@@ -256,6 +277,24 @@ cd_profile_get_scope (CdProfile *profile)
 	return profile->priv->scope;
 }
 
+/**
+ * cd_profile_get_owner:
+ * @profile: a #CdProfile instance.
+ *
+ * Gets the profile owner.
+ *
+ * Return value: The UID of the user that created the device
+ *
+ * Since: 0.1.13
+ **/
+guint
+cd_profile_get_owner (CdProfile *profile)
+{
+	g_return_val_if_fail (CD_IS_PROFILE (profile), G_MAXUINT);
+	g_return_val_if_fail (profile->priv->proxy != NULL, G_MAXUINT);
+	return profile->priv->owner;
+}
+
 /**
  * cd_profile_get_created:
  * @profile: a #CdProfile instance.
@@ -558,6 +597,7 @@ cd_profile_connect_cb (GObject *source_object,
 	GVariant *kind = NULL;
 	GVariant *colorspace = NULL;
 	GVariant *scope = NULL;
+	GVariant *owner = NULL;
 	GVariant *created = NULL;
 	GVariant *has_vcgt = NULL;
 	GVariant *is_system_wide = NULL;
@@ -637,6 +677,12 @@ cd_profile_connect_cb (GObject *source_object,
 	if (scope != NULL)
 		profile->priv->scope = cd_object_scope_from_string (g_variant_get_string (scope, NULL));
 
+	/* get owner */
+	owner = g_dbus_proxy_get_cached_property (profile->priv->proxy,
+						  CD_PROFILE_PROPERTY_OWNER);
+	if (owner != NULL)
+		profile->priv->owner = g_variant_get_uint32 (owner);
+
 	/* get created */
 	created = g_dbus_proxy_get_cached_property (profile->priv->proxy,
 						    CD_PROFILE_PROPERTY_CREATED);
@@ -684,6 +730,8 @@ out:
 		g_variant_unref (colorspace);
 	if (scope != NULL)
 		g_variant_unref (scope);
+	if (owner != NULL)
+		g_variant_unref (owner);
 	if (created != NULL)
 		g_variant_unref (created);
 	if (has_vcgt != NULL)
@@ -1106,6 +1154,9 @@ cd_profile_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
 	case PROP_SCOPE:
 		g_value_set_uint (value, profile->priv->scope);
 		break;
+	case PROP_OWNER:
+		g_value_set_uint (value, profile->priv->owner);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -1318,6 +1369,22 @@ cd_profile_class_init (CdProfileClass *klass)
 							    0,
 							    G_PARAM_READABLE));
 
+	/**
+	 * CdProfile:owner:
+	 *
+	 * The profile owner, e.g. %500.
+	 *
+	 * Since: 0.1.13
+	 **/
+	g_object_class_install_property (object_class,
+					 PROP_OWNER,
+					 g_param_spec_uint ("owner",
+							    NULL, NULL,
+							    0,
+							    G_MAXUINT,
+							    0,
+							    G_PARAM_READABLE));
+
 	g_type_class_add_private (klass, sizeof (CdProfilePrivate));
 }
 
