@@ -33,6 +33,7 @@
 #include "cd-color.h"
 #include "cd-device.h"
 #include "cd-device-sync.h"
+#include "cd-math.h"
 #include "cd-profile.h"
 #include "cd-profile-sync.h"
 #include "cd-sensor.h"
@@ -1997,6 +1998,32 @@ colord_device_duplicate_func (void)
 	g_object_unref (client);
 }
 
+static void
+cd_test_math_func (void)
+{
+	CdMat3x3 mat;
+	CdMat3x3 matsrc;
+
+	/* matrix */
+	mat.m00 = 1.00f;
+	cd_mat33_clear (&mat);
+	g_assert_cmpfloat (mat.m00, <, 0.001f);
+	g_assert_cmpfloat (mat.m00, >, -0.001f);
+	g_assert_cmpfloat (mat.m22, <, 0.001f);
+	g_assert_cmpfloat (mat.m22, >, -0.001f);
+
+	/* multiply two matrices */
+	cd_mat33_clear (&matsrc);
+	matsrc.m01 = matsrc.m10 = 2.0f;
+	cd_mat33_matrix_multiply (&matsrc, &matsrc, &mat);
+	g_assert_cmpfloat (mat.m00, <, 4.1f);
+	g_assert_cmpfloat (mat.m00, >, 3.9f);
+	g_assert_cmpfloat (mat.m11, <, 4.1f);
+	g_assert_cmpfloat (mat.m11, >, 3.9f);
+	g_assert_cmpfloat (mat.m22, <, 0.001f);
+	g_assert_cmpfloat (mat.m22, >, -0.001f);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -2008,6 +2035,7 @@ main (int argc, char **argv)
 
 	/* tests go here */
 	g_test_add_func ("/colord/color", colord_color_func);
+	g_test_add_func ("/colord/math", cd_test_math_func);
 	g_test_add_func ("/colord/device", colord_device_func);
 	g_test_add_func ("/colord/client", colord_client_func);
 	g_test_add_func ("/colord/device-duplicate", colord_device_duplicate_func);
